@@ -23,8 +23,9 @@ use IO::Uncompress::Unzip qw($UnzipError);
 use File::stat;
 #
 my $libver;
-my $CFLAGS
-    = ' -DNDEBUG -DBOOST_DISABLE_ASSERTS -O2 -ffast-math -funroll-loops -fno-align-functions -fno-align-loops';
+my $CFLAGS = ' ';
+
+# = ' -DNDEBUG -DBOOST_DISABLE_ASSERTS -O2 -ffast-math -funroll-loops -fno-align-functions -fno-align-loops';
 my $LDFLAGS = ' ';    # https://wiki.freebsd.org/LinkTimeOptimization
 #
 sub write_file {
@@ -470,7 +471,7 @@ sub Build_PL {
     my $meta = get_meta();
     printf "Creating new 'Build' script for '%s' version '%s'\n", $meta->name, $meta->version;
     my $dir = $meta->name eq 'Module-Build-Tiny' ? "use lib '../lib';" : '';
-    write_file( 'Build', "#!perl\n$dir\nuse lib '.';use " . __PACKAGE__ . ";\nBuild();\n" );
+    write_file( 'Build', "#!$^X\n$dir\nuse lib '.';use " . __PACKAGE__ . ";\nBuild();\n" );
     make_executable('Build');
     my @env = defined $ENV{PERL_MB_OPT} ? split_like_shell( $ENV{PERL_MB_OPT} ) : ();
     write_file( '_build_params', encode_json( [ \@env, \@ARGV ] ) );
