@@ -1,4 +1,4 @@
-package Affix 0.09 {    # 'FFI' is my middle name!
+package Affix 0.10 {    # 'FFI' is my middle name!
     use strict;
     use warnings;
     no warnings 'redefine';
@@ -11,7 +11,8 @@ package Affix 0.09 {    # 'FFI' is my middle name!
     use Carp qw[];
     use vars qw[@EXPORT_OK @EXPORT %EXPORT_TAGS];
     use XSLoader;
-    XSLoader::load( __PACKAGE__, our $VERSION );
+    my $ok = XSLoader::load();
+    END { _shutdown() if $ok; }
     #
     use parent 'Exporter';
     @EXPORT_OK          = sort map { @$_ = sort @$_; @$_ } values %EXPORT_TAGS;
@@ -50,11 +51,23 @@ package Affix 0.09 {    # 'FFI' is my middle name!
                 scalar locate_lib( $_delay{$sub}[1], $_delay{$sub}[2] ) :
                 undef;
 
-            #use Data::Dump;
-            #ddx [ $lib, $_delay{$sub}[3], $sig, $ret, $_delay{$sub}[6] ];
-            my $cv = affix( $lib, $_delay{$sub}[3], $sig, $ret, $_delay{$sub}[6] );
+            #~ use Data::Dump;
+            #~ ddx [
+            #~ $lib, (
+            #~ $_delay{$sub}[3] eq $_delay{$sub}[6] ? $_delay{$sub}[3] :
+            #~ [ $_delay{$sub}[3], $_delay{$sub}[6] ]
+            #~ ),
+            #~ $sig, $ret
+            #~ ];
+            my $cv = affix(
+                $lib, (
+                    $_delay{$sub}[3] eq $_delay{$sub}[6] ? $_delay{$sub}[3] :
+                        [ $_delay{$sub}[3], $_delay{$sub}[6] ]
+                ),
+                $sig, $ret
+            );
             Carp::croak 'Undefined subroutine &' . $_delay{$sub}[6] unless $cv;
-            delete $_delay{$sub};
+            delete $_delay{$sub} if defined $_delay{$sub};
             return &$cv;
         }
 
@@ -111,8 +124,11 @@ package Affix 0.09 {    # 'FFI' is my middle name!
 
                 # TODO: call this defined sub and pass the wrapped symbol and then the passed args
                 #...;
-                return affix( locate_lib( $library, $library_version ),
-                    $symbol, $signature, $return, $full_name );
+                return affix(
+                    locate_lib( $library, $library_version ),
+                    ( $symbol eq $full_name ? $symbol : [ $symbol, $full_name ] ),
+                    $signature, $return
+                );
             }
             $_delay{$full_name}
                 = [ $package, $library, $library_version, $symbol, $signature, $return,
@@ -264,12 +280,6 @@ package Affix 0.09 {    # 'FFI' is my middle name!
         return $_lib_cache->{ $name . ';' . ( $version // '' ) }
             // Carp::croak( 'Cannot locate symbol: ' . $name );
     }
-
-    # define packages that are otherwise XS-only so PAUSE will find them in META.json
-    {
-
-        package Affix::Feature 0.09;
-    }
 };
 1;
 __END__
@@ -284,29 +294,24 @@ Affix - A Foreign Function Interface eXtension
 
     use Affix;
 
+    # bind to exported function
     affix( 'libfoo', 'bar', [Str, Float] => Double );
     print bar( 'Baz', 3.14 );
 
-    # or
-
-    my $bar = wrap( 'libfoo', 'bar', [Str, Float] => Double );
-    print $bar->( 'Baz', 3.14 );
-
-    # or
-
+    # bind to exported function but with sugar
     sub bar : Native('libfoo') : Signature([Str, Float] => Double);
     print bar( 'Baz', 10.9 );
 
-    # bind to exported values
-
+    # wrap an exported function in a code reference
+    my $bar = wrap( 'libfoo', 'bar', [Str, Float] => Double );
+    print $bar->( 'Baz', 3.14 );
 
+    # bind an exported value to a Perl value
+    pin( my $ver, 'libfoo', 'VERSION', Int );
 
 =head1 DESCRIPTION
 
-Affix is a wrapper around L<dyncall|https://dyncall.org/>. If you're looking to
-design your own low level FFI, see L<Dyn.pm|Dyn>.
-
-But if you're just looking for a fast FFI system, keep reading.
+Affix is a wrapper around L<dyncall|https://dyncall.org/>.
 
 Note: This is experimental software and is subject to change as long as this
 disclaimer is here.
@@ -320,6 +325,9 @@ The basic API here is rather simple but not lacking in power.
     affix( 'C:\Windows\System32\user32.dll', 'pow', [Double, Double] => Double );
     warn pow( 3, 5 );
 
+    affix( 'foo', ['foo', 'foobar'] => [ Str ] );
+    foobar( 'Hello' );
+
 Attaches a given symbol in a named perl sub.
 
 Parameters include:
@@ -335,17 +343,18 @@ path of the library as a string or pointer returned by L<< C<dlLoadLibrary( ...
 
 the name of the symbol to call
 
+Optionally, you may provide an array reference with the symbol's name and the
+name of the subroutine
+
 =item C<$parameters>
 
 signature defining argument types in an array
 
 =item C<$return>
 
-return type
+optional return type
 
-=item C<$name>
-
-optional name of affixed sub; C<$symbol_name> by default
+default is C<Void>
 
 =back
 
@@ -690,33 +699,33 @@ code and might not be public in the future.
 
 =head1 Types
 
-While Raku offers a set of native types with a fixed, and known, representation
-in memory but this is Perl so we need to do the work ourselves and design and
-build a pseudo-type system. Affix supports the fundamental types (void, int,
-etc.) and aggregates (struct, array, union).
+Raku offers a set of native types with a fixed, and known, representation in
+memory but this is Perl so we need to do the work ourselves with a pseudo-type
+system. Affix supports the fundamental types (void, int, etc.), aggregates
+(struct, array, union), and .
 
 =head2 Fundamental Types with Native Representation
 
-
-    Affix       C99/C++     Rust    C#          pack()  Raku
-    -----------------------------------------------------------------------
-    Void        void/NULL   ->()    void/NULL   -
-    Bool        _Bool       bool    bool        -       bool
-    Char        int8_t      i8      sbyte       c       int8
-    UChar       uint8_t     u8      byte        C       byte, uint8
-    Short       int16_t     i16     short       s       int16
-    UShort      uint16_t    u16     ushort      S       uint16
-    Int         int32_t     i32     int         i       int32
-    UInt        uint32_t    u32     uint        I       uint32
-    Long        int64_t     i64     long        l       int64, long
-    ULong       uint64_t    u64     ulong       L       uint64, ulong
-    LongLong    -           i128                q       longlong
-    ULongLong   -           u128                Q       ulonglong
-    Float       float       f32                 f       num32
-    Double      double      f64                 d       num64
-    SSize_t     SSize_t                                 SSize_t
-    Size_t      size_t                                  size_t
+    Affix       C99                   Rust    C#          pack()  Raku
+    ----------------------------------------------------------------------------
+    Void        void                  ->()    void/NULL   -
+    Bool        _Bool                 bool    bool        -       bool
+    Char        int8_t                i8      sbyte       c       int8
+    UChar       uint8_t               u8      byte        C       byte, uint8
+    Short       int16_t               i16     short       s       int16
+    UShort      uint16_t              u16     ushort      S       uint16
+    Int         int32_t               i32     int         i       int32
+    UInt        uint32_t              u32     uint        I       uint32
+    Long        int64_t               i64     long        l       int64, long
+    ULong       uint64_t              u64     ulong       L       uint64, ulong
+    LongLong    -/long long           i128                q       longlong
+    ULongLong   -/unsigned long long  u128                Q       ulonglong
+    Float       float                 f32                 f       num32
+    Double      double                f64                 d       num64
+    SSize_t     SSize_t                                           SSize_t
+    Size_t      size_t                                            size_t
     Str         char *
+    WStr        wchar_t
 
 Given sizes are minimums measured in bits
 
@@ -818,6 +827,11 @@ trying using C<Pointer[Char]> and doing it yourself.
 You'll learn a bit more about C<Pointer[...]> and other parameterized types in
 the next section.
 
+=head2 C<WStr>
+
+A null-terminated wide string is a sequence of valid wide characters, ending
+with a null character.
+
 =head1 Parameterized Types
 
 Some types must be provided with more context data.
@@ -1096,7 +1110,7 @@ value.
 
 =head1 See Also
 
-Check out L<FFI::Platypus> for a more robust and mature FFI.
+Check out L<FFI::Platypus> for a more robust and mature FFI
 
 Examples found in C<eg/>.
 
